from json import dump as _dump
from json import load as _load
from os import makedirs as _makedirs
from pathlib import Path
from typing import Any, Optional

from pandas import DataFrame
from pandas import read_csv as _read_csv


def makedirs(path_dir: str) -> None:
    _makedirs(path_dir, exist_ok=True)


def csv_read(
    fpath: str, /, *, index_col: Optional[int] = 0, parse_dates: bool = True
) -> Optional[DataFrame]:
    if not Path(fpath).exists():
        return None
    return _read_csv(fpath, index_col=index_col, parse_dates=parse_dates)


def csv_write(fpath: str, /, df: DataFrame) -> None:
    df.to_csv(fpath)


def json_read(fpath: str, /) -> Optional[Any]:
    if not Path(fpath).exists():
        return None
    with open(fpath, "rt", encoding="UTF-8") as fp:
        return _load(fp)


def json_write(fpath: str, /, data: Any, *, indent: Optional[int] = 4) -> None:
    with open(fpath, "wt", encoding="UTF-8") as fp:
        _dump(data, fp, indent=indent)
